// SPDX-License-Identifier: LGPL-2.1-or-later
//
// SPDX-FileCopyrightText: 2009 Jens-Michael Hoffmann <jensmh@gmx.de>
//

#include "RenderPluginInterface.h"

namespace Marble
{

RenderPluginInterface::~RenderPluginInterface() = default;
}
